@@ -8,10 +8,12 @@ use WWW::Wikipedia::Entry;
 
 use base qw( LWP::UserAgent );
 
-our $VERSION = '1.9';
+our $VERSION = '1.91';
 
 use constant WIKIPEDIA_URL =>
     'http://%s.wikipedia.org/w/index.php?title=%s&action=raw';
+use constant WIKIPEDIA_RAND_URL =>
+    'http://%s.wikipedia.org/wiki/Special:Random';
 
 =head1 NAME
 
@@ -123,7 +125,7 @@ sub search {
 	my $entry = WWW::Wikipedia::Entry->new( $response->content(), $src );
 
         # look for a wikipedia style redirect and process if necessary
-        return $self->search($1) if $entry->text() =~ /^#REDIRECT (.*)/;
+        return $self->search($1) if $entry->text() =~ /^#REDIRECT (.*)/i;
 
 	return( $entry );
     } else {
@@ -133,6 +135,28 @@ sub search {
 
 }
 
+=head2 random()
+
+This method fetches a random wikipedia page.
+
+=cut
+
+sub random {
+    my( $self )  = @_;
+    my $src      = sprintf( WIKIPEDIA_RAND_URL, $self->language() );
+    my $response = $self->get( $src );
+
+    if( $response->is_success() ) {
+        # get the raw version of the current url
+        $src = $response->request->uri . '?action=raw';
+        $response = $self->get( $src );
+        return WWW::Wikipedia::Entry->new( $response->content(), $src );
+    }
+
+    $self->error( "uhoh, WWW::Wikipedia unable to contact " . $src );
+    return;
+}
+
 =head2 error()
 
 This is a generic error accessor/mutator. You can retrieve any searching error
